@@ -5,17 +5,17 @@
 #  define QT_EDITION QT_EDITION_OPENSOURCE
 #endif
 
-#define QT_BUILD_KEY "i386 OpenBSD g++-3.* full-config"
+#define QT_BUILD_KEY "sparc64 OpenBSD g++-3.* full-config"
 
 /* Machine byte-order */
 #define Q_BIG_ENDIAN 4321
 #define Q_LITTLE_ENDIAN 1234
-#define Q_BYTE_ORDER Q_LITTLE_ENDIAN
+#define Q_BYTE_ORDER Q_BIG_ENDIAN
 /* Machine Architecture */
-#define QT_ARCH_I386
+#define QT_ARCH_GENERIC
 /* Compile time features */
 #define QT_LARGEFILE_SUPPORT 64
-#define QT_POINTER_SIZE 4
+#define QT_POINTER_SIZE 8
 
 #if defined(QT_BUILTIN_GIF_READER) && defined(QT_NO_BUILTIN_GIF_READER)
 # undef QT_BUILTIN_GIF_READER
@@ -23,6 +23,12 @@
 # define QT_BUILTIN_GIF_READER 1
 #endif
 
+#if defined(QT_NO_CLOCK_MONOTONIC) && defined(QT_CLOCK_MONOTONIC)
+# undef QT_NO_CLOCK_MONOTONIC
+#elif !defined(QT_NO_CLOCK_MONOTONIC) && !defined(QT_CLOCK_MONOTONIC)
+# define QT_NO_CLOCK_MONOTONIC
+#endif
+
 #if defined(QT_NO_EXCEPTIONS) && defined(QT_EXCEPTIONS)
 # undef QT_NO_EXCEPTIONS
 #elif !defined(QT_NO_EXCEPTIONS) && !defined(QT_EXCEPTIONS)
@@ -41,12 +47,24 @@
 # define QT_NO_IMAGEFORMAT_MNG
 #endif
 
+#if defined(QT_NO_IMAGEFORMAT_TIFF) && defined(QT_IMAGEFORMAT_TIFF)
+# undef QT_NO_IMAGEFORMAT_TIFF
+#elif !defined(QT_NO_IMAGEFORMAT_TIFF) && !defined(QT_IMAGEFORMAT_TIFF)
+# define QT_NO_IMAGEFORMAT_TIFF
+#endif
+
 #if defined(QT_NO_INOTIFY) && defined(QT_INOTIFY)
 # undef QT_NO_INOTIFY
 #elif !defined(QT_NO_INOTIFY) && !defined(QT_INOTIFY)
 # define QT_NO_INOTIFY
 #endif
 
+#if defined(QT_NO_MREMAP) && defined(QT_MREMAP)
+# undef QT_NO_MREMAP
+#elif !defined(QT_NO_MREMAP) && !defined(QT_MREMAP)
+# define QT_NO_MREMAP
+#endif
+
 #if defined(QT_NO_NAS) && defined(QT_NAS)
 # undef QT_NO_NAS
 #elif !defined(QT_NO_NAS) && !defined(QT_NAS)
@@ -65,3 +83,9 @@
 # define QT_NO_ZLIB
 #endif
 
+#if defined(QT_USE_MATH_H_FLOATS) && defined(QT_NO_USE_MATH_H_FLOATS)
+# undef QT_USE_MATH_H_FLOATS
+#elif !defined(QT_USE_MATH_H_FLOATS) && !defined(QT_NO_USE_MATH_H_FLOATS)
+# define QT_USE_MATH_H_FLOATS
+#endif
+
