@@ -1,25 +1,33 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2007 Trolltech ASA. All rights reserved.
 **
-** This file is part of the core module of the Qt Toolkit.
+** This file is part of the QtCore module of the Qt Toolkit.
 **
-** This file may be distributed under the terms of the Q Public License
-** as defined by Trolltech AS of Norway and appearing in the file
-** LICENSE.QPL included in the packaging of this file.
+** This file may be used under the terms of the GNU General Public
+** License version 2.0 as published by the Free Software Foundation
+** and appearing in the file LICENSE.GPL included in the packaging of
+** this file.  Please review the following information to ensure GNU
+** General Public Licensing requirements will be met:
+** http://trolltech.com/products/qt/licenses/licensing/opensource/
 **
-** This file may be distributed and/or modified under the terms of the
-** GNU General Public License version 2 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.
+** If you are unsure which license is appropriate for your use, please
+** review the following information:
+** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
+** or contact the sales department at sales@trolltech.com.
 **
-** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
-**   information about Qt Commercial License Agreements.
-** See http://www.trolltech.com/qpl/ for QPL licensing information.
-** See http://www.trolltech.com/gpl/ for GPL licensing information.
+** In addition, as a special exception, Trolltech gives you certain
+** additional rights. These rights are described in the Trolltech GPL
+** Exception version 1.0, which can be found at
+** http://www.trolltech.com/products/qt/gplexception/ and in the file
+** GPL_EXCEPTION.txt in this package.
 **
-** Contact info@trolltech.com if any conditions of this licensing are
-** not clear to you.
+** In addition, as a special exception, Trolltech, as the sole copyright
+** holder for Qt Designer, grants users of the Qt/Eclipse Integration
+** plug-in the right for the Qt/Eclipse Integration to link to
+** functionality provided by Qt Designer and its related libraries.
+**
+** Trolltech reserves all rights not expressly granted herein.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 ** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
@@ -29,15 +37,20 @@
 #ifndef QMAP_H
 #define QMAP_H
 
-#include "QtCore/qatomic.h"
-#include "QtCore/qiterator.h"
-#include "QtCore/qlist.h"
+#include <QtCore/qatomic.h>
+#include <QtCore/qiterator.h>
+#include <QtCore/qlist.h>
 
 #ifndef QT_NO_STL
 #include <map>
 #endif
 
 #include <new>
+#undef QT_MAP_DEBUG
+
+QT_BEGIN_HEADER
+
+QT_MODULE(Core)
 
 struct Q_CORE_EXPORT QMapData
 {
@@ -47,8 +60,8 @@ struct Q_CORE_EXPORT QMapData
     };
     enum { LastLevel = 11, Sparseness = 3 };
 
-    Node *backward;
-    Node *forward[QMapData::LastLevel + 1];
+    QMapData *backward;
+    QMapData *forward[QMapData::LastLevel + 1];
     QBasicAtomic ref;
     int topLevel;
     int size;
@@ -98,13 +111,6 @@ template <class Ptr> inline bool qMapLessThanKey(const Ptr *key1, const Ptr *key
 }
 #endif // QT_NO_PARTIAL_TEMPLATE_SPECIALIZATION
 
-#if !defined(QT_NO_DATASTREAM)
-class QDataStream;
-template <class Key, class T> class QMap;
-template <class aKey, class aT>
-QDataStream &operator>>(QDataStream &in, QMap<aKey, aT> &map);
-#endif
-
 template <class Key, class T>
 class QMap
 {
@@ -125,11 +131,12 @@ class QMap
         T value;
         QMapData::Node *backward;
     };
-    enum { Payload = sizeof(PayloadNode) - sizeof(QMapData::Node *) };
 
+    static inline int payload() { return sizeof(PayloadNode) - sizeof(QMapData::Node *); }
     static inline Node *concrete(QMapData::Node *node) {
-        return reinterpret_cast<Node *>(reinterpret_cast<char *>(node) - Payload);
+        return reinterpret_cast<Node *>(reinterpret_cast<char *>(node) - payload());
     }
+
 public:
     inline QMap() : d(&QMapData::shared_null) { d->ref.ref(); }
     inline QMap(const QMap<Key, T> &other) : d(other.d)
@@ -152,6 +159,7 @@ public:
     inline void detach() { if (d->ref != 1) detach_helper(); }
     inline bool isDetached() const { return d->ref == 1; }
     inline void setSharable(bool sharable) { if (!sharable) detach(); d->sharable = sharable; }
+    inline void setInsertInOrder(bool ordered) { d->insertInOrder = ordered; }
 
     void clear();
 
@@ -160,11 +168,13 @@ public:
 
     bool contains(const Key &key) const;
     const Key key(const T &value) const;
+    const Key key(const T &value, const Key &defaultKey) const;
     const T value(const Key &key) const;
     const T value(const Key &key, const T &defaultValue) const;
     T &operator[](const Key &key);
     const T operator[](const Key &key) const;
 
+    QList<Key> uniqueKeys() const;
     QList<Key> keys() const;
     QList<Key> keys(const T &value) const;
     QList<T> values() const;
@@ -176,6 +186,7 @@ public:
     class iterator
     {
         QMapData::Node *i;
+
     public:
         typedef std::bidirectional_iterator_tag iterator_category;
         typedef ptrdiff_t difference_type;
@@ -183,6 +194,7 @@ public:
         typedef T *pointer;
         typedef T &reference;
 
+        // ### Qt 5: get rid of 'operator Node *'
         inline operator QMapData::Node *() const { return i; }
         inline iterator() : i(0) { }
         inline iterator(QMapData::Node *node) : i(node) { }
@@ -196,10 +208,6 @@ public:
         inline T *operator->() const { return &concrete(i)->value; }
         inline bool operator==(const iterator &o) const { return i == o.i; }
         inline bool operator!=(const iterator &o) const { return i != o.i; }
-        inline bool operator==(const const_iterator &o) const
-            { return i == reinterpret_cast<const iterator &>(o).i; }
-        inline bool operator!=(const const_iterator &o) const
-            { return i != reinterpret_cast<const iterator &>(o).i; }
 
         inline iterator &operator++() {
             i = i->forward[0];
@@ -224,23 +232,44 @@ public:
         inline iterator operator-(int j) const { return operator+(-j); }
         inline iterator &operator+=(int j) { return *this = *this + j; }
         inline iterator &operator-=(int j) { return *this = *this - j; }
+
+        // ### Qt 5: not sure this is necessary anymore
+#ifdef QT_STRICT_ITERATORS
+    private:
+#else
+    public:
+#endif
+        inline bool operator==(const const_iterator &o) const
+            { return i == reinterpret_cast<const iterator &>(o).i; }
+        inline bool operator!=(const const_iterator &o) const
+            { return i != reinterpret_cast<const iterator &>(o).i; }
+
+    private:
+        // ### Qt 5: remove
+        inline operator bool() const { return false; }
     };
     friend class iterator;
 
     class const_iterator
     {
         QMapData::Node *i;
+
     public:
         typedef std::bidirectional_iterator_tag iterator_category;
         typedef ptrdiff_t difference_type;
         typedef T value_type;
-        typedef T *pointer;
-        typedef T &reference;
+        typedef const T *pointer;
+        typedef const T &reference;
 
+        // ### Qt 5: get rid of 'operator Node *'
         inline operator QMapData::Node *() const { return i; }
         inline const_iterator() : i(0) { }
         inline const_iterator(QMapData::Node *node) : i(node) { }
+#ifdef QT_STRICT_ITERATORS
+        explicit inline const_iterator(const iterator &o)
+#else
         inline const_iterator(const iterator &o)
+#endif
         { i = reinterpret_cast<const const_iterator &>(o).i; }
 
         inline const Key &key() const { return concrete(i)->key; }
@@ -267,7 +296,7 @@ public:
             return *this;
         }
         inline const_iterator operator--(int) {
-            iterator r = *this;
+            const_iterator r = *this;
             i = i->backward;
             return r;
         }
@@ -276,6 +305,17 @@ public:
         inline const_iterator operator-(int j) const { return operator+(-j); }
         inline const_iterator &operator+=(int j) { return *this = *this + j; }
         inline const_iterator &operator-=(int j) { return *this = *this - j; }
+
+        // ### Qt 5: not sure this is necessary anymore
+#ifdef QT_STRICT_ITERATORS
+    private:
+        inline bool operator==(const iterator &o) { return operator==(const_iterator(o)); }
+        inline bool operator!=(const iterator &o) { return operator!=(const_iterator(o)); }
+#endif
+
+    private:
+        // ### Qt 5: remove
+        inline operator bool() const { return false; }
     };
     friend class const_iterator;
 
@@ -301,6 +341,7 @@ public:
     inline int count() const { return d->size; }
     iterator find(const Key &key);
     const_iterator find(const Key &key) const;
+    const_iterator constFind(const Key &key) const;
     iterator lowerBound(const Key &key);
     const_iterator lowerBound(const Key &key) const;
     iterator upperBound(const Key &key);
@@ -316,8 +357,16 @@ public:
     QMap<Key, T> &unite(const QMap<Key, T> &other);
 
     // STL compatibility
+    typedef Key key_type;
+    typedef T mapped_type;
+    typedef ptrdiff_t difference_type;
+    typedef int size_type;
     inline bool empty() const { return isEmpty(); }
 
+#ifdef QT_QMAP_DEBUG
+    inline void dump() const { d->dump(); }
+#endif
+
 private:
     void detach_helper();
     void freeData(QMapData *d);
@@ -325,17 +374,6 @@ private:
     QMapData::Node *mutableFindNode(QMapData::Node *update[], const Key &key) const;
     QMapData::Node *node_create(QMapData *d, QMapData::Node *update[], const Key &key,
                                 const T &value);
-
-#if !defined(QT_NO_DATASTREAM)
-#if !defined(Q_CC_BOR)
-#if defined Q_CC_MSVC && _MSC_VER < 1300
-    friend QDataStream &operator>> (QDataStream &in, QMap &map);
-#else
-    template <class aKey, class aT>
-    friend QDataStream &operator>> (QDataStream &in, QMap<aKey, aT> &map);
-#endif
-#endif
-#endif
 };
 
 template <class Key, class T>
@@ -363,7 +401,7 @@ template <class Key, class T>
 Q_INLINE_TEMPLATE typename QMapData::Node *
 QMap<Key, T>::node_create(QMapData *adt, QMapData::Node *aupdate[], const Key &akey, const T &avalue)
 {
-    QMapData::Node *abstractNode = adt->node_create(aupdate, Payload);
+    QMapData::Node *abstractNode = adt->node_create(aupdate, payload());
     Node *concreteNode = concrete(abstractNode);
     new (&concreteNode->key) Key(akey);
     new (&concreteNode->value) T(avalue);
@@ -391,8 +429,8 @@ Q_INLINE_TEMPLATE QMapData::Node *QMap<Key, T>::findNode(const Key &akey) const
 template <class Key, class T>
 Q_INLINE_TEMPLATE const T QMap<Key, T>::value(const Key &akey) const
 {
-    QMapData::Node *node = findNode(akey);
-    if (node == e) {
+    QMapData::Node *node;
+    if (d->size == 0 || (node = findNode(akey)) == e) {
         return T();
     } else {
         return concrete(node)->value;
@@ -402,8 +440,8 @@ Q_INLINE_TEMPLATE const T QMap<Key, T>::value(const Key &akey) const
 template <class Key, class T>
 Q_INLINE_TEMPLATE const T QMap<Key, T>::value(const Key &akey, const T &adefaultValue) const
 {
-    QMapData::Node *node = findNode(akey);
-    if (node == e) {
+    QMapData::Node *node;
+    if (d->size == 0 || (node = findNode(akey)) == e) {
         return adefaultValue;
     } else {
         return concrete(node)->value;
@@ -501,6 +539,12 @@ Q_INLINE_TEMPLATE typename QMap<Key, T>::const_iterator QMap<Key, T>::find(const
     return const_iterator(findNode(akey));
 }
 
+template <class Key, class T>
+Q_INLINE_TEMPLATE typename QMap<Key, T>::const_iterator QMap<Key, T>::constFind(const Key &akey) const
+{
+    return const_iterator(findNode(akey));
+}
+
 template <class Key, class T>
 Q_INLINE_TEMPLATE typename QMap<Key, T>::iterator QMap<Key, T>::find(const Key &akey)
 {
@@ -513,7 +557,8 @@ Q_INLINE_TEMPLATE QMap<Key, T> &QMap<Key, T>::unite(const QMap<Key, T> &other)
 {
     QMap<Key, T> copy(other);
     const_iterator it = copy.constEnd();
-    while (it != copy.constBegin()) {
+    const const_iterator b = copy.constBegin();
+    while (it != b) {
         --it;
         insertMulti(it.key(), it.value());
     }
@@ -530,12 +575,18 @@ Q_OUTOFLINE_TEMPLATE void QMap<Key, T>::freeData(QMapData *x)
         while (next != y) {
             cur = next;
             next = cur->forward[0];
+#if defined(_MSC_VER) && (_MSC_VER >= 1300)
+#pragma warning(disable:4189)
+#endif
             Node *concreteNode = concrete(cur);
             concreteNode->key.~Key();
             concreteNode->value.~T();
+#if defined(_MSC_VER) && (_MSC_VER >= 1300)
+#pragma warning(default:4189)
+#endif
         }
     }
-    x->continueFreeData(Payload);
+    x->continueFreeData(payload());
 }
 
 template <class Key, class T>
@@ -562,7 +613,7 @@ Q_OUTOFLINE_TEMPLATE int QMap<Key, T>::remove(const Key &akey)
             deleteNext = (next != e && !qMapLessThanKey<Key>(concrete(cur)->key, concrete(next)->key));
             concrete(cur)->key.~Key();
             concrete(cur)->value.~T();
-            d->node_delete(update, Payload, cur);
+            d->node_delete(update, payload(), cur);
         } while (deleteNext);
     }
     return oldSize - d->size;
@@ -587,7 +638,7 @@ Q_OUTOFLINE_TEMPLATE T QMap<Key, T>::take(const Key &akey)
         T t = concrete(next)->value;
         concrete(next)->key.~Key();
         concrete(next)->value.~T();
-        d->node_delete(update, Payload, next);
+        d->node_delete(update, payload(), next);
         return t;
     }
     return T();
@@ -615,7 +666,7 @@ Q_OUTOFLINE_TEMPLATE typename QMap<Key, T>::iterator QMap<Key, T>::erase(iterato
         if (cur == it) {
             concrete(cur)->key.~Key();
             concrete(cur)->value.~T();
-            d->node_delete(update, Payload, cur);
+            d->node_delete(update, payload(), cur);
             return iterator(next);
         }
 
@@ -669,6 +720,25 @@ Q_OUTOFLINE_TEMPLATE QMapData::Node *QMap<Key, T>::mutableFindNode(QMapData::Nod
     }
 }
 
+template <class Key, class T>
+Q_OUTOFLINE_TEMPLATE QList<Key> QMap<Key, T>::uniqueKeys() const
+{
+    QList<Key> res;
+    const_iterator i = begin();
+    if (i != end()) {
+        for (;;) {
+            const Key &aKey = i.key();
+            res.append(aKey);
+            do {
+                if (++i == end())
+                    goto break_out_of_outer_loop;
+            } while (!(aKey < i.key()));   // loop while (key == i.key())
+        }
+    }
+break_out_of_outer_loop:
+    return res;
+}
+
 template <class Key, class T>
 Q_OUTOFLINE_TEMPLATE QList<Key> QMap<Key, T>::keys() const
 {
@@ -696,6 +766,12 @@ Q_OUTOFLINE_TEMPLATE QList<Key> QMap<Key, T>::keys(const T &avalue) const
 
 template <class Key, class T>
 Q_OUTOFLINE_TEMPLATE const Key QMap<Key, T>::key(const T &avalue) const
+{
+    return key(avalue, Key());
+}
+
+template <class Key, class T>
+Q_OUTOFLINE_TEMPLATE const Key QMap<Key, T>::key(const T &avalue, const Key &defaultKey) const
 {
     const_iterator i = begin();
     while (i != end()) {
@@ -704,7 +780,7 @@ Q_OUTOFLINE_TEMPLATE const Key QMap<Key, T>::key(const T &avalue) const
         ++i;
     }
 
-    return Key();
+    return defaultKey;
 }
 
 template <class Key, class T>
@@ -803,13 +879,13 @@ Q_OUTOFLINE_TEMPLATE QMap<Key, T>::QMap(const std::map<Key, T> &other)
 }
 
 template <class Key, class T>
-Q_OUTOFLINE_TEMPLATE  std::map<Key, T> QMap<Key, T>::toStdMap() const
+Q_OUTOFLINE_TEMPLATE std::map<Key, T> QMap<Key, T>::toStdMap() const
 {
     std::map<Key, T> map;
     const_iterator it = end();
     while (it != begin()) {
         --it;
-        map.insert((*it).first, (*it).second);
+        map.insert(std::pair<Key, T>(it.key(), it.value()));
     }
     return map;
 }
@@ -823,29 +899,112 @@ public:
     QMultiMap() {}
     QMultiMap(const QMap<Key, T> &other) : QMap<Key, T>(other) {}
 
-    inline typename QMap<Key, T>::iterator replace(const Key &key, const T &value);
-    inline typename QMap<Key, T>::iterator insert(const Key &key, const T &value);
+    inline typename QMap<Key, T>::iterator replace(const Key &key, const T &value)
+    { return QMap<Key, T>::insert(key, value); }
+    inline typename QMap<Key, T>::iterator insert(const Key &key, const T &value)
+    { return QMap<Key, T>::insertMulti(key, value); }
 
     inline QMultiMap &operator+=(const QMultiMap &other)
     { unite(other); return *this; }
     inline QMultiMap operator+(const QMultiMap &other) const
     { QMultiMap result = *this; result += other; return result; }
 
+#ifndef Q_NO_USING_KEYWORD
+    using QMap<Key, T>::contains;
+    using QMap<Key, T>::remove;
+    using QMap<Key, T>::count;
+    using QMap<Key, T>::find;
+    using QMap<Key, T>::constFind;
+#else
+    inline bool contains(const Key &key) const
+    { return QMap<Key, T>::contains(key); }
+    inline int remove(const Key &key)
+    { return QMap<Key, T>::remove(key); }
+    inline int count(const Key &key) const
+    { return QMap<Key, T>::count(key); }
+    inline int count() const
+    { return QMap<Key, T>::count(); }
+    inline typename QMap<Key, T>::iterator find(const Key &key)
+    { return QMap<Key, T>::find(key); }
+    inline typename QMap<Key, T>::const_iterator find(const Key &key) const
+    { return QMap<Key, T>::find(key); }
+    inline typename QMap<Key, T>::const_iterator constFind(const Key &key) const
+    { return QMap<Key, T>::constFind(key); }
+#endif
+
+    bool contains(const Key &key, const T &value) const;
+
+    int remove(const Key &key, const T &value);
+
+    int count(const Key &key, const T &value) const;
+
+    typename QMap<Key, T>::iterator find(const Key &key, const T &value) {
+        typename QMap<Key, T>::iterator i(find(key));
+        typename QMap<Key, T>::iterator end(this->end());
+        while (i != end && !qMapLessThanKey<Key>(key, i.key())) {
+            if (i.value() == value)
+                return i;
+            ++i;
+        }
+        return end;
+    }
+    typename QMap<Key, T>::const_iterator find(const Key &key, const T &value) const {
+        typename QMap<Key, T>::const_iterator i(constFind(key));
+        typename QMap<Key, T>::const_iterator end(QMap<Key, T>::constEnd());
+        while (i != end && !qMapLessThanKey<Key>(key, i.key())) {
+            if (i.value() == value)
+                return i;
+            ++i;
+        }
+        return end;
+    }
+    typename QMap<Key, T>::const_iterator constFind(const Key &key, const T &value) const
+        { return find(key, value); }
 private:
     T &operator[](const Key &key);
     const T operator[](const Key &key) const;
 };
 
 template <class Key, class T>
-Q_INLINE_TEMPLATE Q_TYPENAME QMap<Key, T>::iterator QMultiMap<Key, T>::replace(const Key &akey, const T &avalue)
-{ return QMap<Key, T>::insert(akey, avalue); }
+Q_INLINE_TEMPLATE bool QMultiMap<Key, T>::contains(const Key &key, const T &value) const
+{
+    return constFind(key, value) != QMap<Key, T>::constEnd();
+}
 
 template <class Key, class T>
-Q_INLINE_TEMPLATE Q_TYPENAME QMap<Key, T>::iterator QMultiMap<Key, T>::insert(const Key &akey, const T &avalue)
-{ return QMap<Key, T>::insertMulti(akey, avalue); }
+Q_INLINE_TEMPLATE int QMultiMap<Key, T>::remove(const Key &key, const T &value)
+{
+    int n = 0;
+    typename QMap<Key, T>::iterator i(find(key));
+    typename QMap<Key, T>::const_iterator end(QMap<Key, T>::constEnd());
+    while (i != end && !qMapLessThanKey<Key>(key, i.key())) {
+        if (i.value() == value) {
+            i = erase(i);
+            ++n;
+        } else {
+            ++i;
+        }
+    }
+    return n;
+}
 
+template <class Key, class T>
+Q_INLINE_TEMPLATE int QMultiMap<Key, T>::count(const Key &key, const T &value) const
+{
+    int n = 0;
+    typename QMap<Key, T>::const_iterator i(constFind(key));
+    typename QMap<Key, T>::const_iterator end(QMap<Key, T>::constEnd());
+    while (i != end && !qMapLessThanKey<Key>(key, i.key())) {
+        if (i.value() == value)
+            ++n;
+        ++i;
+    }
+    return n;
+}
 
 Q_DECLARE_ASSOCIATIVE_ITERATOR(Map)
 Q_DECLARE_MUTABLE_ASSOCIATIVE_ITERATOR(Map)
 
+QT_END_HEADER
+
 #endif // QMAP_H
