@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2007 Trolltech ASA. All rights reserved.
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
@@ -9,12 +9,25 @@
 ** and appearing in the file LICENSE.GPL included in the packaging of
 ** this file.  Please review the following information to ensure GNU
 ** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** http://trolltech.com/products/qt/licenses/licensing/opensource/
 **
 ** If you are unsure which license is appropriate for your use, please
 ** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
+** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
+** or contact the sales department at sales@trolltech.com.
+**
+** In addition, as a special exception, Trolltech gives you certain
+** additional rights. These rights are described in the Trolltech GPL
+** Exception version 1.0, which can be found at
+** http://www.trolltech.com/products/qt/gplexception/ and in the file
+** GPL_EXCEPTION.txt in this package.
+**
+** In addition, as a special exception, Trolltech, as the sole copyright
+** holder for Qt Designer, grants users of the Qt/Eclipse Integration
+** plug-in the right for the Qt/Eclipse Integration to link to
+** functionality provided by Qt Designer and its related libraries.
+**
+** Trolltech reserves all rights not expressly granted herein.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 ** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
@@ -29,6 +42,8 @@
 #include <QtCore/qvariant.h>
 #include <QtCore/qvector.h>
 
+QT_BEGIN_HEADER
+
 QT_MODULE(Gui)
 
 #ifndef QT_NO_TREEWIDGET
@@ -36,14 +51,16 @@ QT_MODULE(Gui)
 class QTreeWidget;
 class QTreeModel;
 class QWidgetItemData;
+class QTreeWidgetItemPrivate;
 
 class Q_GUI_EXPORT QTreeWidgetItem
 {
     friend class QTreeModel;
     friend class QTreeWidget;
     friend class QTreeWidgetItemIterator;
+    friend class QTreeWidgetItemPrivate;
 public:
-    enum { Type = 0, UserType = 1000 };
+    enum ItemType { Type = 0, UserType = 1000 };
     QTreeWidgetItem(int type = Type);
     QTreeWidgetItem(const QStringList &strings, int type = Type);
     explicit QTreeWidgetItem(QTreeWidget *view, int type = Type);
@@ -59,8 +76,27 @@ public:
 
     inline QTreeWidget *treeWidget() const { return view; }
 
-    inline Qt::ItemFlags flags() const { return itemFlags; }
-    inline void setFlags(Qt::ItemFlags flags);
+    inline void setSelected(bool select);
+    inline bool isSelected() const;
+
+    inline void setHidden(bool hide);
+    inline bool isHidden() const;
+
+    inline void setExpanded(bool expand);
+    inline bool isExpanded() const;
+
+    inline void setFirstColumnSpanned(bool span);
+    inline bool isFirstColumnSpanned() const;
+
+    inline void setDisabled(bool disabled);
+    inline bool isDisabled() const;
+
+    enum ChildIndicatorPolicy { ShowIndicator, DontShowIndicator, DontShowIndicatorWhenChildless };
+    void setChildIndicatorPolicy(QTreeWidgetItem::ChildIndicatorPolicy policy);
+    QTreeWidgetItem::ChildIndicatorPolicy childIndicatorPolicy() const;
+
+    Qt::ItemFlags flags() const;
+    void setFlags(Qt::ItemFlags flags);
 
     inline QString text(int column) const
         { return data(column, Qt::DisplayRole).toString(); }
@@ -100,11 +136,21 @@ public:
     inline void setBackgroundColor(int column, const QColor &color)
         { setData(column, Qt::BackgroundColorRole, color); }
 
+    inline QBrush background(int column) const
+        { return qvariant_cast<QBrush>(data(column, Qt::BackgroundRole)); }
+    inline void setBackground(int column, const QBrush &brush)
+        { setData(column, Qt::BackgroundRole, brush); }
+
     inline QColor textColor(int column) const
         { return qvariant_cast<QColor>(data(column, Qt::TextColorRole)); }
     inline void setTextColor(int column, const QColor &color)
         { setData(column, Qt::TextColorRole, color); }
 
+    inline QBrush foreground(int column) const
+        { return qvariant_cast<QBrush>(data(column, Qt::ForegroundRole)); }
+    inline void setForeground(int column, const QBrush &brush)
+        { setData(column, Qt::ForegroundRole, brush); }
+
     inline Qt::CheckState checkState(int column) const
         { return static_cast<Qt::CheckState>(data(column, Qt::CheckStateRole).toInt()); }
     inline void setCheckState(int column, Qt::CheckState state)
@@ -127,14 +173,18 @@ public:
     QTreeWidgetItem &operator=(const QTreeWidgetItem &other);
 
     inline QTreeWidgetItem *parent() const { return par; }
-    inline QTreeWidgetItem *child(int index) const
-        { if (index < 0 || index >= children.size()) return 0; return children.at(index); }
+    inline QTreeWidgetItem *child(int index) const {
+        if (index < 0 || index >= children.size())
+            return 0;
+        return children.at(index);
+    }
     inline int childCount() const { return children.count(); }
     inline int columnCount() const { return values.count(); }
     inline int indexOfChild(QTreeWidgetItem *child) const;
 
     void addChild(QTreeWidgetItem *child);
     void insertChild(int index, QTreeWidgetItem *child);
+    void removeChild(QTreeWidgetItem *child);
     QTreeWidgetItem *takeChild(int index);
 
     void addChildren(const QList<QTreeWidgetItem*> &children);
@@ -142,24 +192,24 @@ public:
     QList<QTreeWidgetItem*> takeChildren();
 
     inline int type() const { return rtti; }
-
+    inline void sortChildren(int column, Qt::SortOrder order)
+        { sortChildren(column, order, false); }
 private:
     void sortChildren(int column, Qt::SortOrder order, bool climb);
     QVariant childrenCheckState(int column) const;
+    void itemChanged();
+    void executePendingSort() const;
 
     int rtti;
     // One item has a vector of column entries. Each column has a vector of (role, value) pairs.
     QVector< QVector<QWidgetItemData> > values;
     QTreeWidget *view;
-    QTreeModel *model;
+    QTreeWidgetItemPrivate *d;
     QTreeWidgetItem *par;
     QList<QTreeWidgetItem*> children;
     Qt::ItemFlags itemFlags;
 };
 
-inline void QTreeWidgetItem::setFlags(Qt::ItemFlags aflags)
-{ itemFlags = aflags; }
-
 inline void QTreeWidgetItem::setText(int column, const QString &atext)
 { setData(column, Qt::DisplayRole, atext); }
 
@@ -185,7 +235,7 @@ inline void QTreeWidgetItem::setFont(int column, const QFont &afont)
 { setData(column, Qt::FontRole, afont); }
 
 inline int QTreeWidgetItem::indexOfChild(QTreeWidgetItem *achild) const
-{ return children.indexOf(achild); }
+{ (void)const_cast<QTreeWidgetItem*>(this)->takeChild(-1); return children.indexOf(achild); }
 
 #ifndef QT_NO_DATASTREAM
 Q_GUI_EXPORT QDataStream &operator<<(QDataStream &out, const QTreeWidgetItem &item);
@@ -198,7 +248,6 @@ class Q_GUI_EXPORT QTreeWidget : public QTreeView
 {
     Q_OBJECT
     Q_PROPERTY(int columnCount READ columnCount WRITE setColumnCount)
-    Q_PROPERTY(bool sortingEnabled READ isSortingEnabled WRITE setSortingEnabled)
     Q_PROPERTY(int topLevelItemCount READ topLevelItemCount)
 
     friend class QTreeModel;
@@ -209,12 +258,14 @@ public:
     int columnCount() const;
     void setColumnCount(int columns);
 
+    QTreeWidgetItem *invisibleRootItem() const;
     QTreeWidgetItem *topLevelItem(int index) const;
     int topLevelItemCount() const;
     void insertTopLevelItem(int index, QTreeWidgetItem *item);
     void addTopLevelItem(QTreeWidgetItem *item);
     QTreeWidgetItem *takeTopLevelItem(int index);
-    int indexOfTopLevelItem(QTreeWidgetItem *item);
+    int indexOfTopLevelItem(QTreeWidgetItem *item); // ### Qt 5: remove me
+    int indexOfTopLevelItem(QTreeWidgetItem *item) const;
 
     void insertTopLevelItems(int index, const QList<QTreeWidgetItem*> &items);
     void addTopLevelItems(const QList<QTreeWidgetItem*> &items);
@@ -222,6 +273,7 @@ public:
     QTreeWidgetItem *headerItem() const;
     void setHeaderItem(QTreeWidgetItem *item);
     void setHeaderLabels(const QStringList &labels);
+    inline void setHeaderLabel(const QString &label);
 
     QTreeWidgetItem *currentItem() const;
     int currentColumn() const;
@@ -243,11 +295,13 @@ public:
 
     QWidget *itemWidget(QTreeWidgetItem *item, int column) const;
     void setItemWidget(QTreeWidgetItem *item, int column, QWidget *widget);
+    inline void removeItemWidget(QTreeWidgetItem *item, int column);
 
     bool isItemSelected(const QTreeWidgetItem *item) const;
     void setItemSelected(const QTreeWidgetItem *item, bool select);
     QList<QTreeWidgetItem*> selectedItems() const;
-    QList<QTreeWidgetItem*> findItems(const QString &text, Qt::MatchFlags flags, int column = 0) const;
+    QList<QTreeWidgetItem*> findItems(const QString &text, Qt::MatchFlags flags,
+                                      int column = 0) const;
 
     bool isItemHidden(const QTreeWidgetItem *item) const;
     void setItemHidden(const QTreeWidgetItem *item, bool hide);
@@ -255,8 +309,15 @@ public:
     bool isItemExpanded(const QTreeWidgetItem *item) const;
     void setItemExpanded(const QTreeWidgetItem *item, bool expand);
 
+    bool isFirstItemColumnSpanned(const QTreeWidgetItem *item) const;
+    void setFirstItemColumnSpanned(const QTreeWidgetItem *item, bool span);
+
+    QTreeWidgetItem *itemAbove(const QTreeWidgetItem *item) const;
+    QTreeWidgetItem *itemBelow(const QTreeWidgetItem *item) const;
+
 public Q_SLOTS:
-    void scrollToItem(const QTreeWidgetItem *item, QAbstractItemView::ScrollHint hint = EnsureVisible);
+    void scrollToItem(const QTreeWidgetItem *item,
+                      QAbstractItemView::ScrollHint hint = EnsureVisible);
     void expandItem(const QTreeWidgetItem *item);
     void collapseItem(const QTreeWidgetItem *item);
     void clear();
@@ -284,6 +345,7 @@ protected:
 
     QModelIndex indexFromItem(QTreeWidgetItem *item, int column = 0) const;
     QTreeWidgetItem *itemFromIndex(const QModelIndex &index) const;
+    void dropEvent(QDropEvent *event);
 
 private:
     void setModel(QAbstractItemModel *model);
@@ -291,21 +353,61 @@ private:
     Q_DECLARE_PRIVATE(QTreeWidget)
     Q_DISABLE_COPY(QTreeWidget)
 
-    Q_PRIVATE_SLOT(d_func(), void emitItemPressed(const QModelIndex &index))
-    Q_PRIVATE_SLOT(d_func(), void emitItemClicked(const QModelIndex &index))
-    Q_PRIVATE_SLOT(d_func(), void emitItemDoubleClicked(const QModelIndex &index))
-    Q_PRIVATE_SLOT(d_func(), void emitItemActivated(const QModelIndex &index))
-    Q_PRIVATE_SLOT(d_func(), void emitItemEntered(const QModelIndex &index))
-    Q_PRIVATE_SLOT(d_func(), void emitItemChanged(const QModelIndex &index))
-    Q_PRIVATE_SLOT(d_func(), void emitItemExpanded(const QModelIndex &index))
-    Q_PRIVATE_SLOT(d_func(), void emitItemCollapsed(const QModelIndex &index))
-    Q_PRIVATE_SLOT(d_func(), void emitCurrentItemChanged(const QModelIndex &previous, const QModelIndex &current))
-
+    Q_PRIVATE_SLOT(d_func(), void _q_emitItemPressed(const QModelIndex &index))
+    Q_PRIVATE_SLOT(d_func(), void _q_emitItemClicked(const QModelIndex &index))
+    Q_PRIVATE_SLOT(d_func(), void _q_emitItemDoubleClicked(const QModelIndex &index))
+    Q_PRIVATE_SLOT(d_func(), void _q_emitItemActivated(const QModelIndex &index))
+    Q_PRIVATE_SLOT(d_func(), void _q_emitItemEntered(const QModelIndex &index))
+    Q_PRIVATE_SLOT(d_func(), void _q_emitItemChanged(const QModelIndex &index))
+    Q_PRIVATE_SLOT(d_func(), void _q_emitItemExpanded(const QModelIndex &index))
+    Q_PRIVATE_SLOT(d_func(), void _q_emitItemCollapsed(const QModelIndex &index))
+    Q_PRIVATE_SLOT(d_func(), void _q_emitCurrentItemChanged(const QModelIndex &previous, const QModelIndex &current))
+    Q_PRIVATE_SLOT(d_func(), void _q_sort())
+    Q_PRIVATE_SLOT(d_func(), void _q_dataChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight))
+    Q_PRIVATE_SLOT(d_func(), void _q_itemsSorted())
 };
 
+inline void QTreeWidget::removeItemWidget(QTreeWidgetItem *item, int column)
+{ setItemWidget(item, column, 0); }
+
 inline QTreeWidgetItem *QTreeWidget::itemAt(int ax, int ay) const
 { return itemAt(QPoint(ax, ay)); }
 
+inline void QTreeWidget::setHeaderLabel(const QString &alabel)
+{ setHeaderLabels(QStringList(alabel)); }
+
+inline void QTreeWidgetItem::setSelected(bool aselect)
+{ if (view) view->setItemSelected(this, aselect); }
+
+inline bool QTreeWidgetItem::isSelected() const
+{ return (view ? view->isItemSelected(this) : false); }
+
+inline void QTreeWidgetItem::setHidden(bool ahide)
+{ if (view) view->setItemHidden(this, ahide); }
+
+inline bool QTreeWidgetItem::isHidden() const
+{ return (view ? view->isItemHidden(this) : false); }
+
+inline void QTreeWidgetItem::setExpanded(bool aexpand)
+{ if (view) view->setItemExpanded(this, aexpand); }
+
+inline bool QTreeWidgetItem::isExpanded() const
+{ return (view ? view->isItemExpanded(this) : false); }
+
+inline void QTreeWidgetItem::setFirstColumnSpanned(bool aspan)
+{ if (view) view->setFirstItemColumnSpanned(this, aspan); }
+
+inline bool QTreeWidgetItem::isFirstColumnSpanned() const
+{ return (view ? view->isFirstItemColumnSpanned(this) : false); }
+
+inline void QTreeWidgetItem::setDisabled(bool disabled)
+{ setFlags(disabled ? (flags() & ~Qt::ItemIsEnabled) : flags() | Qt::ItemIsEnabled); }
+
+inline bool QTreeWidgetItem::isDisabled() const
+{ return !(flags() & Qt::ItemIsEnabled); }
+
 #endif // QT_NO_TREEWIDGET
 
+QT_END_HEADER
+
 #endif // QTREEWIDGET_H
