@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2007 Trolltech ASA. All rights reserved.
 **
 ** This file is part of the Qt3Support module of the Qt Toolkit.
 **
@@ -9,12 +9,25 @@
 ** and appearing in the file LICENSE.GPL included in the packaging of
 ** this file.  Please review the following information to ensure GNU
 ** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** http://trolltech.com/products/qt/licenses/licensing/opensource/
 **
 ** If you are unsure which license is appropriate for your use, please
 ** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
+** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
+** or contact the sales department at sales@trolltech.com.
+**
+** In addition, as a special exception, Trolltech gives you certain
+** additional rights. These rights are described in the Trolltech GPL
+** Exception version 1.0, which can be found at
+** http://www.trolltech.com/products/qt/gplexception/ and in the file
+** GPL_EXCEPTION.txt in this package.
+**
+** In addition, as a special exception, Trolltech, as the sole copyright
+** holder for Qt Designer, grants users of the Qt/Eclipse Integration
+** plug-in the right for the Qt/Eclipse Integration to link to
+** functionality provided by Qt Designer and its related libraries.
+**
+** Trolltech reserves all rights not expressly granted herein.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 ** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
@@ -34,6 +47,8 @@
 #include <Qt3Support/q3intdict.h>
 #include <QtCore/qstringlist.h>
 
+QT_BEGIN_HEADER
+
 QT_MODULE(Qt3Support)
 
 class Q3TableHeader;
@@ -42,7 +57,7 @@ class Q3Table;
 class QPaintEvent;
 class QTimer;
 class QResizeEvent;
-class QComboBox;
+class Q3ComboBox;
 class QCheckBox;
 class Q3DragObject;
 
@@ -173,11 +188,11 @@ public:
     QSize sizeHint() const;
 
 private:
-    QComboBox *cb;
+    Q3ComboBox *cb;
     QStringList entries;
     int current;
     bool edit;
-    static QComboBox *fakeCombo;
+    static Q3ComboBox *fakeCombo;
     static QWidget *fakeComboWidget;
     static int fakeRef;
 
@@ -518,4 +533,6 @@ private:
     Q_DISABLE_COPY(Q3Table)
 };
 
+QT_END_HEADER
+
 #endif // Q3TABLE_H
