@@ -5,17 +5,17 @@
 #  define QT_EDITION QT_EDITION_OPENSOURCE
 #endif
 
-#define QT_BUILD_KEY "alpha OpenBSD g++-3.* full-config"
+#define QT_BUILD_KEY "i386 OpenBSD g++-3.* full-config"
 
 /* Machine byte-order */
 #define Q_BIG_ENDIAN 4321
 #define Q_LITTLE_ENDIAN 1234
 #define Q_BYTE_ORDER Q_LITTLE_ENDIAN
 /* Machine Architecture */
-#define QT_ARCH_ALPHA
+#define QT_ARCH_I386
 /* Compile time features */
 #define QT_LARGEFILE_SUPPORT 64
-#define QT_POINTER_SIZE 8
+#define QT_POINTER_SIZE 4
 
 #if defined(QT_BUILTIN_GIF_READER) && defined(QT_NO_BUILTIN_GIF_READER)
 # undef QT_BUILTIN_GIF_READER
