@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2006 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2007 Trolltech ASA. All rights reserved.
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
@@ -9,12 +9,25 @@
 ** and appearing in the file LICENSE.GPL included in the packaging of
 ** this file.  Please review the following information to ensure GNU
 ** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** http://trolltech.com/products/qt/licenses/licensing/opensource/
 **
 ** If you are unsure which license is appropriate for your use, please
 ** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
+** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
+** or contact the sales department at sales@trolltech.com.
+**
+** In addition, as a special exception, Trolltech gives you certain
+** additional rights. These rights are described in the Trolltech GPL
+** Exception version 1.0, which can be found at
+** http://www.trolltech.com/products/qt/gplexception/ and in the file
+** GPL_EXCEPTION.txt in this package.
+**
+** In addition, as a special exception, Trolltech, as the sole copyright
+** holder for Qt Designer, grants users of the Qt/Eclipse Integration
+** plug-in the right for the Qt/Eclipse Integration to link to
+** functionality provided by Qt Designer and its related libraries.
+**
+** Trolltech reserves all rights not expressly granted herein.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 ** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
@@ -132,13 +145,15 @@ public:
     bool contains(const QPoint &p, bool proper=false) const;
     bool contains(int x, int y) const; // inline methods, _don't_ merge these
     bool contains(int x, int y, bool proper) const;
-    bool contains(const QRect &r, bool proper=false) const;
-    QRect unite(const QRect &r) const;
-    QRect intersect(const QRect &r) const;
+    bool contains(const QRect &r, bool proper = false) const;
+    QRect unite(const QRect &r) const;  // ### Qt 5: make QT4_SUPPORT
+    QRect united(const QRect &other) const;
+    QRect intersect(const QRect &r) const;  // ### Qt 5: make QT4_SUPPORT
+    QRect intersected(const QRect &other) const;
     bool intersects(const QRect &r) const;
 
-    friend Q_CORE_EXPORT inline bool operator==(const QRect &, const QRect &);
-    friend Q_CORE_EXPORT inline bool operator!=(const QRect &, const QRect &);
+    friend Q_CORE_EXPORT_INLINE bool operator==(const QRect &, const QRect &);
+    friend Q_CORE_EXPORT_INLINE bool operator!=(const QRect &, const QRect &);
 
 #ifdef QT3_SUPPORT
     inline QT3_SUPPORT void rect(int *x, int *y, int *w, int *h) const { getRect(x, y, w, h); }
@@ -165,8 +180,8 @@ private:
 };
 Q_DECLARE_TYPEINFO(QRect, Q_MOVABLE_TYPE);
 
-Q_CORE_EXPORT inline bool operator==(const QRect &, const QRect &);
-Q_CORE_EXPORT inline bool operator!=(const QRect &, const QRect &);
+Q_CORE_EXPORT_INLINE bool operator==(const QRect &, const QRect &);
+Q_CORE_EXPORT_INLINE bool operator!=(const QRect &, const QRect &);
 
 
 /*****************************************************************************
@@ -454,11 +469,22 @@ inline QRect QRect::intersect(const QRect &r) const
 {
     return *this & r;
 }
+
+inline QRect QRect::intersected(const QRect &other) const
+{
+    return intersect(other);
+}
+
 inline QRect QRect::unite(const QRect &r) const
 {
     return *this | r;
 }
 
+inline QRect QRect::united(const QRect &r) const
+{
+     return unite(r);
+}
+
 inline bool operator==(const QRect &r1, const QRect &r2)
 {
     return r1.x1==r2.x1 && r1.x2==r2.x2 && r1.y1==r2.y1 && r1.y2==r2.y2;
@@ -479,6 +505,7 @@ class Q_CORE_EXPORT QRectF
 public:
     QRectF() { xp = yp = 0.; w = h = 0.; }
     QRectF(const QPointF &topleft, const QSizeF &size);
+    QRectF(const QPointF &topleft, const QPointF &bottomRight);
     QRectF(qreal left, qreal top, qreal width, qreal height);
     QRectF(const QRect &rect);
 
@@ -555,14 +582,17 @@ public:
     bool contains(const QPointF &p) const;
     bool contains(qreal x, qreal y) const;
     bool contains(const QRectF &r) const;
-    QRectF unite(const QRectF &r) const;
-    QRectF intersect(const QRectF &r) const;
+    QRectF unite(const QRectF &r) const;  // ### Qt 5: make QT4_SUPPORT
+    QRectF united(const QRectF &other) const;
+    QRectF intersect(const QRectF &r) const;  // ### Qt 5: make QT4_SUPPORT
+    QRectF intersected(const QRectF &other) const;
     bool intersects(const QRectF &r) const;
 
-    friend Q_CORE_EXPORT inline bool operator==(const QRectF &, const QRectF &);
-    friend Q_CORE_EXPORT inline bool operator!=(const QRectF &, const QRectF &);
+    friend Q_CORE_EXPORT_INLINE bool operator==(const QRectF &, const QRectF &);
+    friend Q_CORE_EXPORT_INLINE bool operator!=(const QRectF &, const QRectF &);
 
     QRect toRect() const;
+    QRect toAlignedRect() const;
 
 private:
     qreal xp;
@@ -572,8 +602,8 @@ private:
 };
 Q_DECLARE_TYPEINFO(QRectF, Q_MOVABLE_TYPE);
 
-Q_CORE_EXPORT inline bool operator==(const QRectF &, const QRectF &);
-Q_CORE_EXPORT inline bool operator!=(const QRectF &, const QRectF &);
+Q_CORE_EXPORT_INLINE bool operator==(const QRectF &, const QRectF &);
+Q_CORE_EXPORT_INLINE bool operator!=(const QRectF &, const QRectF &);
 
 
 /*****************************************************************************
@@ -601,6 +631,14 @@ inline QRectF::QRectF(const QPointF &atopLeft, const QSizeF &asize)
     h = asize.height();
 }
 
+inline QRectF::QRectF(const QPointF &atopLeft, const QPointF &abottomRight)
+{
+    xp = atopLeft.x();
+    yp = atopLeft.y();
+    w = abottomRight.x() - xp;
+    h = abottomRight.y() - yp;
+}
+
 inline QRectF::QRectF(const QRect &r)
     : xp(r.x()), yp(r.y()), w(r.width()), h(r.height())
 {
@@ -768,11 +806,22 @@ inline QRectF QRectF::intersect(const QRectF &r) const
 {
     return *this & r;
 }
+
+inline QRectF QRectF::intersected(const QRectF &r) const
+{
+    return intersect(r);
+}
+
 inline QRectF QRectF::unite(const QRectF &r) const
 {
     return *this | r;
 }
 
+inline QRectF QRectF::united(const QRectF &r) const
+{
+    return unite(r);
+}
+
 inline bool operator==(const QRectF &r1, const QRectF &r2)
 {
     return qFuzzyCompare(r1.xp, r2.xp) && qFuzzyCompare(r1.yp, r2.yp)
