@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2007 Trolltech ASA. All rights reserved.
 **
 ** This file is part of the Qt Designer of the Qt Toolkit.
 **
@@ -9,12 +9,25 @@
 ** and appearing in the file LICENSE.GPL included in the packaging of
 ** this file.  Please review the following information to ensure GNU
 ** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** http://trolltech.com/products/qt/licenses/licensing/opensource/
 **
 ** If you are unsure which license is appropriate for your use, please
 ** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
+** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
+** or contact the sales department at sales@trolltech.com.
+**
+** In addition, as a special exception, Trolltech gives you certain
+** additional rights. These rights are described in the Trolltech GPL
+** Exception version 1.0, which can be found at
+** http://www.trolltech.com/products/qt/gplexception/ and in the file
+** GPL_EXCEPTION.txt in this package.
+**
+** In addition, as a special exception, Trolltech, as the sole copyright
+** holder for Qt Designer, grants users of the Qt/Eclipse Integration
+** plug-in the right for the Qt/Eclipse Integration to link to
+** functionality provided by Qt Designer and its related libraries.
+**
+** Trolltech reserves all rights not expressly granted herein.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 ** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
@@ -27,8 +40,10 @@
 #include <QtDesigner/sdk_global.h>
 #include <QtDesigner/extension.h>
 
+QT_BEGIN_HEADER
+
 class DomWidget;
-class DomUi;
+class DomUI;
 class QWidget;
 
 class QDesignerFormEditorInterface;
@@ -41,8 +56,8 @@ public:
     virtual QDesignerFormEditorInterface *core() const = 0;
     virtual QWidget *widget() const = 0;
 
-    virtual bool saveUiExtraInfo(DomUi *ui) = 0;
-    virtual bool loadUiExtraInfo(DomUi *ui) = 0;
+    virtual bool saveUiExtraInfo(DomUI *ui) = 0;
+    virtual bool loadUiExtraInfo(DomUI *ui) = 0;
 
     virtual bool saveWidgetExtraInfo(DomWidget *ui_widget) = 0;
     virtual bool loadWidgetExtraInfo(DomWidget *ui_widget) = 0;
@@ -53,7 +68,9 @@ public:
 private:
     QString m_workingDirectory;
 };
-Q_DECLARE_EXTENSION_INTERFACE(QDesignerExtraInfoExtension, "com.trolltech.Qt.Designer.ExtraInfo")
+Q_DECLARE_EXTENSION_INTERFACE(QDesignerExtraInfoExtension, "com.trolltech.Qt.Designer.ExtraInfo.2")
 
 
+QT_END_HEADER
+
 #endif // EXTRAINFO_H
