@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2007 Trolltech ASA. All rights reserved.
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
@@ -9,12 +9,25 @@
 ** and appearing in the file LICENSE.GPL included in the packaging of
 ** this file.  Please review the following information to ensure GNU
 ** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** http://trolltech.com/products/qt/licenses/licensing/opensource/
 **
 ** If you are unsure which license is appropriate for your use, please
 ** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
+** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
+** or contact the sales department at sales@trolltech.com.
+**
+** In addition, as a special exception, Trolltech gives you certain
+** additional rights. These rights are described in the Trolltech GPL
+** Exception version 1.0, which can be found at
+** http://www.trolltech.com/products/qt/gplexception/ and in the file
+** GPL_EXCEPTION.txt in this package.
+**
+** In addition, as a special exception, Trolltech, as the sole copyright
+** holder for Qt Designer, grants users of the Qt/Eclipse Integration
+** plug-in the right for the Qt/Eclipse Integration to link to
+** functionality provided by Qt Designer and its related libraries.
+**
+** Trolltech reserves all rights not expressly granted herein.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 ** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
@@ -26,6 +39,8 @@
 
 #include <QtGui/qaccessible.h>
 
+QT_BEGIN_HEADER
+
 QT_MODULE(Gui)
 
 #ifndef QT_NO_ACCESSIBILITY
@@ -54,7 +69,34 @@ protected:
     virtual ~QAccessibleObject();
 
 private:
+    friend class QAccessibleObjectEx;
     QAccessibleObjectPrivate *d;
+    Q_DISABLE_COPY(QAccessibleObject)
+};
+
+class Q_GUI_EXPORT QAccessibleObjectEx : public QAccessibleInterfaceEx
+{
+public:
+    explicit QAccessibleObjectEx(QObject *object);
+
+    bool isValid() const;
+    QObject *object() const;
+
+    // properties
+    QRect rect(int child) const;
+    void setText(Text t, int child, const QString &text);
+
+    // actions
+    int userActionCount(int child) const;
+    bool doAction(int action, int child, const QVariantList &params);
+    QString actionText(int action, Text t, int child) const;
+
+protected:
+    virtual ~QAccessibleObjectEx();
+
+private:
+    QAccessibleObjectPrivate *d;
+    Q_DISABLE_COPY(QAccessibleObjectEx)
 };
 
 class Q_GUI_EXPORT QAccessibleApplication : public QAccessibleObject
@@ -84,4 +126,6 @@ public:
 
 #endif // QT_NO_ACCESSIBILITY
 
+QT_END_HEADER
+
 #endif // QACCESSIBLEOBJECT_H
