@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2007 Trolltech ASA. All rights reserved.
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
@@ -9,12 +9,25 @@
 ** and appearing in the file LICENSE.GPL included in the packaging of
 ** this file.  Please review the following information to ensure GNU
 ** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** http://trolltech.com/products/qt/licenses/licensing/opensource/
 **
 ** If you are unsure which license is appropriate for your use, please
 ** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
+** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
+** or contact the sales department at sales@trolltech.com.
+**
+** In addition, as a special exception, Trolltech gives you certain
+** additional rights. These rights are described in the Trolltech GPL
+** Exception version 1.0, which can be found at
+** http://www.trolltech.com/products/qt/gplexception/ and in the file
+** GPL_EXCEPTION.txt in this package.
+**
+** In addition, as a special exception, Trolltech, as the sole copyright
+** holder for Qt Designer, grants users of the Qt/Eclipse Integration
+** plug-in the right for the Qt/Eclipse Integration to link to
+** functionality provided by Qt Designer and its related libraries.
+**
+** Trolltech reserves all rights not expressly granted herein.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 ** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
@@ -26,6 +39,8 @@
 
 #include <QtGui/qwindowdefs.h>
 
+QT_BEGIN_HEADER
+
 QT_MODULE(Gui)
 
 #ifndef QT_NO_FONTDIALOG
@@ -41,6 +56,8 @@ class Q_GUI_EXPORT QFontDialog: public QDialog
     Q_DECLARE_PRIVATE(QFontDialog)
 
 public:
+    // ### Qt5: merge overloads
+    static QFont getFont(bool *ok, const QFont &def, QWidget* parent, const QString &caption);
     static QFont getFont(bool *ok, const QFont &def, QWidget* parent=0);
     static QFont getFont(bool *ok, QWidget* parent=0);
 
@@ -51,10 +68,12 @@ public:
         { Q_UNUSED(name); return getFont(ok, parent); }
 #endif
 
+protected:
+    void changeEvent(QEvent *e);
 private:
     static QFont getFont(bool *ok, const QFont *def, QWidget* parent=0);
 
-    explicit QFontDialog(QWidget* parent=0, bool modal=false, Qt::WFlags f=0);
+    explicit QFontDialog(QWidget* parent=0, bool modal=false, Qt::WindowFlags f=0);
     ~QFontDialog();
 
     QFont font() const;
@@ -67,16 +86,18 @@ private:
     void updateSizes();
 
 private:
-    Q_PRIVATE_SLOT(d_func(), void sizeChanged(const QString &))
-    Q_PRIVATE_SLOT(d_func(), void familyHighlighted(int))
-    Q_PRIVATE_SLOT(d_func(), void writingSystemHighlighted(int))
-    Q_PRIVATE_SLOT(d_func(), void styleHighlighted(int))
-    Q_PRIVATE_SLOT(d_func(), void sizeHighlighted(int))
-    Q_PRIVATE_SLOT(d_func(), void updateSample())
+    Q_PRIVATE_SLOT(d_func(), void _q_sizeChanged(const QString &))
+    Q_PRIVATE_SLOT(d_func(), void _q_familyHighlighted(int))
+    Q_PRIVATE_SLOT(d_func(), void _q_writingSystemHighlighted(int))
+    Q_PRIVATE_SLOT(d_func(), void _q_styleHighlighted(int))
+    Q_PRIVATE_SLOT(d_func(), void _q_sizeHighlighted(int))
+    Q_PRIVATE_SLOT(d_func(), void _q_updateSample())
 
     Q_DISABLE_COPY(QFontDialog)
 };
 
 #endif // QT_NO_FONTDIALOG
 
+QT_END_HEADER
+
 #endif // QFONTDIALOG_H
