@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2007 Trolltech ASA. All rights reserved.
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
@@ -9,12 +9,25 @@
 ** and appearing in the file LICENSE.GPL included in the packaging of
 ** this file.  Please review the following information to ensure GNU
 ** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** http://trolltech.com/products/qt/licenses/licensing/opensource/
 **
 ** If you are unsure which license is appropriate for your use, please
 ** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
+** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
+** or contact the sales department at sales@trolltech.com.
+**
+** In addition, as a special exception, Trolltech gives you certain
+** additional rights. These rights are described in the Trolltech GPL
+** Exception version 1.0, which can be found at
+** http://www.trolltech.com/products/qt/gplexception/ and in the file
+** GPL_EXCEPTION.txt in this package.
+**
+** In addition, as a special exception, Trolltech, as the sole copyright
+** holder for Qt Designer, grants users of the Qt/Eclipse Integration
+** plug-in the right for the Qt/Eclipse Integration to link to
+** functionality provided by Qt Designer and its related libraries.
+**
+** Trolltech reserves all rights not expressly granted herein.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 ** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
@@ -26,6 +39,8 @@
 
 #include <QtCore/qmimedata.h>
 
+QT_BEGIN_HEADER
+
 QT_MODULE(Gui)
 
 class Q_GUI_EXPORT QMimeSource
@@ -86,22 +101,22 @@ private:
 
 /*
   Encapsulation of conversion between MIME and Mac flavor.
-  Not need on X11, as the underlying protocol uses the MIME standard
+  Not needed on X11, as the underlying protocol uses the MIME standard
   directly.
 */
 
-class Q_GUI_EXPORT QMacMime {
+class Q_GUI_EXPORT QMacMime { //Obsolete
     char type;
 public:
     enum QMacMimeType { MIME_DND=0x01, MIME_CLIP=0x02, MIME_QT_CONVERTOR=0x04, MIME_ALL=MIME_DND|MIME_CLIP };
-    explicit QMacMime(char);
-    virtual ~QMacMime();
+    explicit QMacMime(char) { }
+    virtual ~QMacMime() { }
 
-    static void initialize();
+    static void initialize() { }
 
-    static QList<QMacMime*> all(QMacMimeType);
-    static QMacMime *convertor(QMacMimeType, const QString &mime, int flav);
-    static QString flavorToMime(QMacMimeType, int flav);
+    static QList<QMacMime*> all(QMacMimeType) { return QList<QMacMime*>(); }
+    static QMacMime *convertor(QMacMimeType, const QString &, int) { return 0; }
+    static QString flavorToMime(QMacMimeType, int) { return QString(); }
 
     virtual QString convertorName()=0;
     virtual int countFlavors()=0;
@@ -113,6 +128,35 @@ public:
     virtual QList<QByteArray> convertFromMime(const QString &mime, QVariant data, int flav)=0;
 };
 
+class Q_GUI_EXPORT QMacPasteboardMime {
+    char type;
+public:
+    enum QMacPasteboardMimeType { MIME_DND=0x01,
+                                  MIME_CLIP=0x02,
+                                  MIME_QT_CONVERTOR=0x04,
+                                  MIME_QT3_CONVERTOR=0x08,
+                                  MIME_ALL=MIME_DND|MIME_CLIP
+    };
+    explicit QMacPasteboardMime(char);
+    virtual ~QMacPasteboardMime();
+
+    static void initialize();
+
+    static QList<QMacPasteboardMime*> all(uchar);
+    static QMacPasteboardMime *convertor(uchar, const QString &mime, QString flav);
+    static QString flavorToMime(uchar, QString flav);
+
+    virtual QString convertorName() = 0;
+
+    virtual bool canConvert(const QString &mime, QString flav) = 0;
+    virtual QString mimeFor(QString flav) = 0;
+    virtual QString flavorFor(const QString &mime) = 0;
+    virtual QVariant convertToMime(const QString &mime, QList<QByteArray> data, QString flav) = 0;
+    virtual QList<QByteArray> convertFromMime(const QString &mime, QVariant data, QString flav) = 0;
+};
+
 #endif // Q_WS_MAC
 
+QT_END_HEADER
+
 #endif // QMIME_H
