@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2006 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2007 Trolltech ASA. All rights reserved.
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
@@ -9,12 +9,25 @@
 ** and appearing in the file LICENSE.GPL included in the packaging of
 ** this file.  Please review the following information to ensure GNU
 ** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** http://trolltech.com/products/qt/licenses/licensing/opensource/
 **
 ** If you are unsure which license is appropriate for your use, please
 ** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
+** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
+** or contact the sales department at sales@trolltech.com.
+**
+** In addition, as a special exception, Trolltech gives you certain
+** additional rights. These rights are described in the Trolltech GPL
+** Exception version 1.0, which can be found at
+** http://www.trolltech.com/products/qt/gplexception/ and in the file
+** GPL_EXCEPTION.txt in this package.
+**
+** In addition, as a special exception, Trolltech, as the sole copyright
+** holder for Qt Designer, grants users of the Qt/Eclipse Integration
+** plug-in the right for the Qt/Eclipse Integration to link to
+** functionality provided by Qt Designer and its related libraries.
+**
+** Trolltech reserves all rights not expressly granted herein.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 ** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
@@ -26,6 +39,7 @@
 
 #include <QtCore/qobject.h>
 #include <QtCore/qsize.h>
+#include <QtCore/qrect.h>
 #include <QtGui/qfont.h>
 
 QT_BEGIN_HEADER
@@ -48,6 +62,7 @@ class QTextCodec;
 class QUrl;
 class QVariant;
 class QRectF;
+class QTextOption;
 
 template<typename T> class QVector;
 
@@ -93,6 +108,12 @@ class Q_GUI_EXPORT QTextDocument : public QObject
     Q_PROPERTY(QSizeF pageSize READ pageSize WRITE setPageSize)
     Q_PROPERTY(QFont defaultFont READ defaultFont WRITE setDefaultFont)
     Q_PROPERTY(bool useDesignMetrics READ useDesignMetrics WRITE setUseDesignMetrics)
+    Q_PROPERTY(QSizeF size READ size)
+    Q_PROPERTY(qreal textWidth READ textWidth WRITE setTextWidth)
+    Q_PROPERTY(int blockCount READ blockCount)
+    Q_PROPERTY(QString defaultStyleSheet READ defaultStyleSheet WRITE setDefaultStyleSheet)
+    Q_PROPERTY(int maximumBlockCount READ maximumBlockCount WRITE setMaximumBlockCount)
+    QDOC_PROPERTY(QTextOption defaultTextOption READ defaultTextOption WRITE setDefaultTextOption)
 
 public:
     explicit QTextDocument(QObject *parent = 0);
@@ -133,8 +154,11 @@ public:
     };
     Q_DECLARE_FLAGS(FindFlags, FindFlag)
 
-    QTextCursor find(const QString &expr, int from = 0, FindFlags options = 0) const;
-    QTextCursor find(const QString &expr, const QTextCursor &from, FindFlags options = 0) const;
+    QTextCursor find(const QString &subString, int from = 0, FindFlags options = 0) const;
+    QTextCursor find(const QString &subString, const QTextCursor &from, FindFlags options = 0) const;
+
+    QTextCursor find(const QRegExp &expr, int from = 0, FindFlags options = 0) const;
+    QTextCursor find(const QRegExp &expr, const QTextCursor &from, FindFlags options = 0) const;
 
     QTextFrame *frameAt(int pos) const;
     QTextFrame *rootFrame() const;
@@ -159,10 +183,11 @@ public:
 #ifndef QT_NO_PRINTER
     void print(QPrinter *printer) const;
 #endif
-    
+
     enum ResourceType {
         HtmlResource  = 1,
         ImageResource = 2,
+        StyleSheetResource = 3,
 
         UserResource  = 100
     };
@@ -177,6 +202,30 @@ public:
     void setUseDesignMetrics(bool b);
     bool useDesignMetrics() const;
 
+    void drawContents(QPainter *painter, const QRectF &rect = QRectF());
+
+    void setTextWidth(qreal width);
+    qreal textWidth() const;
+
+    qreal idealWidth() const;
+
+    void adjustSize();
+    QSizeF size() const;
+
+    int blockCount() const;
+
+    void setDefaultStyleSheet(const QString &sheet);
+    QString defaultStyleSheet() const;
+
+    void undo(QTextCursor *cursor);
+    void redo(QTextCursor *cursor);
+
+    int maximumBlockCount() const;
+    void setMaximumBlockCount(int maximum);
+
+    QTextOption defaultTextOption() const;
+    void setDefaultTextOption(const QTextOption &option);
+
 Q_SIGNALS:
     void contentsChange(int from, int charsRemoves, int charsAdded);
     void contentsChanged();
@@ -184,6 +233,7 @@ Q_SIGNALS:
     void redoAvailable(bool);
     void modificationChanged(bool m);
     void cursorPositionChanged(const QTextCursor &cursor);
+    void blockCountChanged(int newBlockCount);
 
 public Q_SLOTS:
     void undo();
@@ -195,6 +245,7 @@ protected:
     virtual QTextObject *createObject(const QTextFormat &f);
     virtual QVariant loadResource(int type, const QUrl &name);
 
+    QTextDocument(QTextDocumentPrivate &dd, QObject *parent);
 public:
     QTextDocumentPrivate *docHandle() const;
 private:
