@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2007 Trolltech ASA. All rights reserved.
 **
 ** This file is part of the QtXML module of the Qt Toolkit.
 **
@@ -9,12 +9,25 @@
 ** and appearing in the file LICENSE.GPL included in the packaging of
 ** this file.  Please review the following information to ensure GNU
 ** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** http://trolltech.com/products/qt/licenses/licensing/opensource/
 **
 ** If you are unsure which license is appropriate for your use, please
 ** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
+** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
+** or contact the sales department at sales@trolltech.com.
+**
+** In addition, as a special exception, Trolltech gives you certain
+** additional rights. These rights are described in the Trolltech GPL
+** Exception version 1.0, which can be found at
+** http://www.trolltech.com/products/qt/gplexception/ and in the file
+** GPL_EXCEPTION.txt in this package.
+**
+** In addition, as a special exception, Trolltech, as the sole copyright
+** holder for Qt Designer, grants users of the Qt/Eclipse Integration
+** plug-in the right for the Qt/Eclipse Integration to link to
+** functionality provided by Qt Designer and its related libraries.
+**
+** Trolltech reserves all rights not expressly granted herein.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 ** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
@@ -26,6 +39,8 @@
 
 #include <QtCore/qstring.h>
 
+QT_BEGIN_HEADER
+
 QT_MODULE(Xml)
 
 #ifndef QT_NO_DOM
@@ -123,6 +138,12 @@ public:
         CharacterDataNode         = 22 // this is not in the standard
     };
 
+    enum EncodingPolicy
+    {
+        EncodingFromDocument      = 1,
+        EncodingFromTextStream    = 2
+    };
+
     QDomNode();
     QDomNode(const QDomNode&);
     QDomNode& operator= (const QDomNode&);
@@ -201,6 +222,7 @@ public:
     QDomComment toComment() const;
 
     void save(QTextStream&, int) const;
+    void save(QTextStream&, int, EncodingPolicy) const; // ### Qt 5: Merge overload(if we at all keep this)
 
     QDomElement firstChildElement(const QString &tagName = QString()) const;
     QDomElement lastChildElement(const QString &tagName = QString()) const;
@@ -644,4 +666,6 @@ Q_XML_EXPORT QTextStream& operator<<(QTextStream&, const QDomNode&);
 
 #endif // QT_NO_DOM
 
+QT_END_HEADER
+
 #endif // QDOM_H
